# CHANGELOG

<!-- version list -->

## v1.2.0 (2026-01-07)


## v1.1.0 (2026-01-07)


## v1.0.3 (2026-01-07)

### Bug Fixes

- Add Dockerfile to new project generation
  ([`3cc8ecd`](https://github.com/jupyter-naas/abi/commit/3cc8ecddd80e247b10c7273862f5cfffb33969c5))

- Update config.yaml template on new project generation
  ([`72a174e`](https://github.com/jupyter-naas/abi/commit/72a174efdc779374f4035b3c91ba2aaf035ff6ce))


## v1.0.2 (2025-12-19)


## v1.0.1 (2025-12-19)

### Bug Fixes

- Add missing config in template
  ([`d4df148`](https://github.com/jupyter-naas/abi/commit/d4df148450f356a94ab53b46580db20bbba325b1))


## v1.0.0 (2025-12-19)

- Initial Release
